@@ -795,7 +795,7 @@ check_for_composite_types(migratorContext *ctx, Cluster whichCluster)
 	bool		found = false;
 	char		output_path[MAXPGPATH];
 
-	prep_status(ctx, "Checking for user columns of composite types");
+	prep_status(ctx, "Checking for columns with user-defined composite types");
 
 	snprintf(output_path, sizeof(output_path), "%s/tables_using_composite_types.txt",
 			ctx->home_dir);
@@ -888,7 +888,7 @@ check_for_array_types(migratorContext *ctx, Cluster whichCluster)
 	bool		found = false;
 	char		output_path[MAXPGPATH];
 
-	prep_status(ctx, "Checking for user columns of array types");
+	prep_status(ctx, "Checking for columns with user-defined array types");
 
 	snprintf(output_path, sizeof(output_path), "%s/tables_using_array_types.txt",
 			ctx->home_dir);
@@ -985,7 +985,7 @@ check_for_enum_types(migratorContext *ctx, Cluster whichCluster)
 	bool		found = false;
 	char		output_path[MAXPGPATH];
 
-	prep_status(ctx, "Checking for user columns of enum types");
+	prep_status(ctx, "Checking for columns with user-defined enum types");
 
 	snprintf(output_path, sizeof(output_path), "%s/tables_using_enum_types.txt",
 			ctx->home_dir);
